@@ -38,11 +38,12 @@ def main() :
     parser = argparse.ArgumentParser(description=description)
     parser.add_argument('-c','--config', help = 'Specifies yaml-config file',default='config_demo.yaml')
     parser.add_argument('-r','--conflict', help = 'Conflict handling flag of \'vctl vrep import\'')
-    parser.add_argument('artifact_type', help='Type of artifacts',choices=achoices)
+    parser.add_argument('artifact_type', help='Type of artifacts. \'bundle\'- only supports .tgz-files with differnt artifact types.',choices=achoices)
     parser.add_argument('artifact', help='Artifact file(tgz) or directory')
-    parser.add_argument('-s', '--solution', help='Solution name if upload should be exported to repository')
-    parser.add_argument('-v', '--version', help='Version of solution. Necessary if exported to repository',default='0.0.1')
-    parser.add_argument('-u', '--user', help='SAP Data Intelligence user (not for \'solutions\')')
+    parser.add_argument('-n', '--solution', help='Solution name if uploaded artificats should be exported to solution repository as well.')
+    parser.add_argument('-s', '--description', help='Description string for solution.')
+    parser.add_argument('-v', '--version', help='Version of solution. Necessary if exported to solution repository.',default='0.0.1')
+    parser.add_argument('-u', '--user', help='SAP Data Intelligence user if different from login-user. Not applicable for solutions-upload')
     args = parser.parse_args()
 
     config_file = 'config.yaml'
@@ -80,7 +81,7 @@ def main() :
             basename = args.artifact
         basename = path.basename(basename)
         source = path.join(VFLOW_PATHS[args.artifact_type],basename)
-        export_solution_to_repo(source,args.solution,args.version)
+        export_solution_to_repo(source,args.solution,args.version,args.description)
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
